@@ -10,7 +10,7 @@ use Cwd;
 use File::Path;
 our @ISA = qw( Module::Build );
 
-our $VERSION ='0.33';
+our $VERSION ='0.35';
 
 sub process_xs_files {
 	my $self = shift;
@@ -19,6 +19,20 @@ sub process_xs_files {
 	# We will be doing our own custom XS file handling
 }
 
+sub hipi_build_target {
+	my $self = shift;
+	return $self->{_hipi_build_target} if $self->{_hipi_build_target};
+	my $perlversion = $^V;
+	$perlversion =~ s/^v//;
+	my($major, $minor, $release) = split(/\./, $perlversion);
+	if ($minor <= 14 ) {
+        $self->{_hipi_build_target} = 'wheezy';
+    } else {
+		$self->{_hipi_build_target} = 'current';
+	}
+    return $self->{_hipi_build_target};
+}
+
 sub hipi_run_command {
 	my ($self, $cmds) = @_;
 	my $cmd = join( ' ', @$cmds );
@@ -40,14 +54,16 @@ sub ACTION_clean {
     $self->SUPER::ACTION_clean;
     File::Path::remove_tree('BCM2835/buildlib') if -d 'BCM2835/buildlib';
     unlink('mylib/lib/libwiringPiStatic.a');
+	unlink('mylib/lib/libwiringPiDevStatic.a');
     unlink('mylib/lib/libbcm2835Static.a');
+	unlink('suidbin/hipi-i2c');
+	unlink('suidbin/hipi-pud');
     chdir('Wiring/src/wiringPi');
     system('make clean');
     chdir('../../../');
-    chdir('suidbin');
-    system('make -f makefile.gcc realclean');
+	chdir('Wiring/src/devLib');
+    system('make clean');
     chdir('../../../');
-    chdir
 }
 
 sub ACTION_build {
@@ -133,13 +149,9 @@ sub hipi_do_depends {
         libfile-copy-recursive-perl
         libpar-dist-perl
         libwww-perl
-        libopengl-perl
         libtext-patch-perl
         libtext-diff-perl
         libmodule-info-perl
-        libthreads-perl
-        libthreads-shared-perl
-        libthread-queue-perl
         libio-multiplex-perl
         i2c-tools
         git
@@ -147,6 +159,12 @@ sub hipi_do_depends {
         libperl-dev
         libio-epoll-perl
     );
+	
+	
+	if ( $self->hipi_build_target eq 'wheezy') {
+        push @debs, ( 'libopengl-perl', 'libthreads-perl','libthreads-shared-perl','libthread-queue-perl' );
+    }
+    
     
 #   libdbd-pg-perl
 #	libdbd-mysql-perl
@@ -176,7 +194,7 @@ sub hipi_do_wx {
         Alien::wxWidgets->import;
         my $widgversion = Alien::wxWidgets->version;
         # require version 0.9922 and 2.009004
-        if( $wxversion > 0.9921 && $widgversion > 2.009003 ) {
+        if( $wxversion > 0.9927 && $widgversion > 2.009003 ) {
             $wxrequired = 0;
         }
     };
@@ -195,9 +213,8 @@ sub hipi_build_wiring_library {
     $self->log_info(qq(Building wiringPi library\n));
     mkdir( 'mylib/lib', 0777 ) if !-d 'mylib/lib';
     my $tgtlib = 'mylib/lib/libwiringPiStatic.a';
-    return if $self->up_to_date( 'Build', $tgtlib );
-    
-    chdir('Wiring/src/wiringPi');
+	my $tgtlibDev = 'mylib/lib/libwiringPiDevStatic.a';
+    return if( $self->up_to_date( 'Build', $tgtlib ) && $self->up_to_date( 'Build', $tgtlibDev ) );
     
     my $gcc = $Config{cc};
     $gcc = 'gcc' if $gcc eq 'cc';
@@ -208,13 +225,17 @@ sub hipi_build_wiring_library {
     my @cmd = (
 		qq(make static CC=$gcc CXX=$gxx LD=$gld),
 	);
-
+	chdir('Wiring/src/wiringPi');
+	$self->hipi_run_command( \@cmd );
+	chdir('../../../');
+	chdir('Wiring/src/devLib');
 	$self->hipi_run_command( \@cmd );
     chdir('../../../');
-    
     # copy the lib
     my $srclib = 'Wiring/src/wiringPi/libwiringPi.a';
+	my $srclibDev = 'Wiring/src/devLib/libwiringPiDev.a';
     File::Copy::copy( $srclib, $tgtlib );
+	File::Copy::copy( $srclibDev, $tgtlibDev );
 }
 
 sub hipi_build_bcm2835_library {
@@ -269,7 +290,7 @@ sub hipi_build_xs {
         { name => 'I2C',  version => $VERSION, autopath => 'HiPi/Device/I2C', libs => '' },
         { name => 'SPI',  version => $VERSION, autopath => 'HiPi/Device/SPI', libs => '' },
         { name => 'BCM2835', version => $VERSION, autopath => 'HiPi/BCM2835', libs => '-Lmylib/lib -lbcm2835Static' },
-        { name => 'Wiring',  version => $VERSION, autopath => 'HiPi/Wiring',  libs => '-Lmylib/lib -lwiringPiStatic -lpthread' },
+        { name => 'Wiring',  version => $VERSION, autopath => 'HiPi/Wiring',  libs => '-Lmylib/lib -lwiringPiStatic -lwiringPiDevStatic -lpthread' },
     );
     
     #----------------------------------------------
