@@ -2,7 +2,7 @@
 # Package       HiPi::BCM2835
 # Description:  Wrapper for bcm2835 C library - Access to /dev/mem
 # Created       Fri Nov 23 13:55:49 2012
-# SVN Id        $Id: BCM2835.pm 1759 2013-04-27 13:53:07Z Mark Dootson $
+# SVN Id        $Id: BCM2835.pm 22 2016-03-04 21:38:30Z Mark Dootson $
 # Copyright:    Copyright (c) 2012 Mark Dootson
 # Licence:      This work is free software; you can redistribute it and/or modify it 
 #               under the terms of the GNU General Public License as published by the 
@@ -23,10 +23,10 @@ use parent qw( HiPi::Device );
 use XSLoader;
 use Carp;
 use HiPi;
-use HiPi::Utils qw( is_raspberry );
+use HiPi::Utils qw( is_raspberry is_raspberry_2);
 use HiPi::Constant qw( :raspberry :spi :i2c);
 
-our $VERSION ='0.33';
+our $VERSION ='0.35';
 
 if( is_raspberry ) {
     XSLoader::load('HiPi::BCM2835', $VERSION);
@@ -43,6 +43,7 @@ our $_memmapped : shared;
 
 sub bcm2835_init {
     lock $_memmapped;
+    
     unless( $_memmapped ) {
         _hipi_bcm2835_init() or croak 'Failed to initialise libbcm2835';
         $_memmapped = 1;
@@ -350,6 +351,33 @@ use constant {
     RPI_V2_GPIO_P5_05     => 30,  #  Version 2, Pin P5-05
     RPI_V2_GPIO_P5_06     => 31,  #  Version 2, Pin P5-06
     
+    RPI_BPLUS_GPIO_J8_03     =>  2, #  /*!< B+, Pin J8-03 */
+    RPI_BPLUS_GPIO_J8_05     =>  3, #  /*!< B+, Pin J8-05 */
+    RPI_BPLUS_GPIO_J8_07     =>  4, #  /*!< B+, Pin J8-07 */
+    RPI_BPLUS_GPIO_J8_08     => 14, #  /*!< B+, Pin J8-08, defaults to alt function 0 UART0_TXD */
+    RPI_BPLUS_GPIO_J8_10     => 15, #  /*!< B+, Pin J8-10, defaults to alt function 0 UART0_RXD */
+    RPI_BPLUS_GPIO_J8_11     => 17, #  /*!< B+, Pin J8-11 */
+    RPI_BPLUS_GPIO_J8_12     => 18, #  /*!< B+, Pin J8-12, can be PWM channel 0 in ALT FUN 5 */
+    RPI_BPLUS_GPIO_J8_13     => 27, #  /*!< B+, Pin J8-13 */
+    RPI_BPLUS_GPIO_J8_15     => 22, #  /*!< B+, Pin J8-15 */
+    RPI_BPLUS_GPIO_J8_16     => 23, #  /*!< B+, Pin J8-16 */
+    RPI_BPLUS_GPIO_J8_18     => 24, #  /*!< B+, Pin J8-18 */
+    RPI_BPLUS_GPIO_J8_19     => 10, #  /*!< B+, Pin J8-19, MOSI when SPI0 in use */
+    RPI_BPLUS_GPIO_J8_21     =>  9, #  /*!< B+, Pin J8-21, MISO when SPI0 in use */
+    RPI_BPLUS_GPIO_J8_22     => 25, #  /*!< B+, Pin J8-22 */
+    RPI_BPLUS_GPIO_J8_23     => 11, #  /*!< B+, Pin J8-23, CLK when SPI0 in use */
+    RPI_BPLUS_GPIO_J8_24     =>  8, #  /*!< B+, Pin J8-24, CE0 when SPI0 in use */
+    RPI_BPLUS_GPIO_J8_26     =>  7, #  /*!< B+, Pin J8-26, CE1 when SPI0 in use */
+    RPI_BPLUS_GPIO_J8_29     =>  5, #/*!< B+, Pin J8-29,  */
+    RPI_BPLUS_GPIO_J8_31     =>  6, #/*!< B+, Pin J8-31,  */
+    RPI_BPLUS_GPIO_J8_32     =>  12, #/*!< B+, Pin J8-32,  */
+    RPI_BPLUS_GPIO_J8_33     =>  13, #/*!< B+, Pin J8-33,  */
+    RPI_BPLUS_GPIO_J8_35     =>  19, #/*!< B+, Pin J8-35,  */
+    RPI_BPLUS_GPIO_J8_36     =>  16, #/*!< B+, Pin J8-36,  */
+    RPI_BPLUS_GPIO_J8_37     =>  26, #/*!< B+, Pin J8-37,  */
+    RPI_BPLUS_GPIO_J8_38     =>  20, #/*!< B+, Pin J8-38,  */
+    RPI_BPLUS_GPIO_J8_40     =>  21, #/*!< B+, Pin J8-40,  
+    
 };
 
 _register_exported_constants( qw(
@@ -392,7 +420,35 @@ _register_exported_constants( qw(
     RPI_V2_GPIO_P5_03
     RPI_V2_GPIO_P5_04
     RPI_V2_GPIO_P5_05
-    RPI_V2_GPIO_P5_06   
+    RPI_V2_GPIO_P5_06
+    
+    RPI_BPLUS_GPIO_J8_03
+    RPI_BPLUS_GPIO_J8_05
+    RPI_BPLUS_GPIO_J8_07
+    RPI_BPLUS_GPIO_J8_08
+    RPI_BPLUS_GPIO_J8_10
+    RPI_BPLUS_GPIO_J8_11
+    RPI_BPLUS_GPIO_J8_12
+    RPI_BPLUS_GPIO_J8_13
+    RPI_BPLUS_GPIO_J8_15
+    RPI_BPLUS_GPIO_J8_16
+    RPI_BPLUS_GPIO_J8_18
+    RPI_BPLUS_GPIO_J8_19
+    RPI_BPLUS_GPIO_J8_21
+    RPI_BPLUS_GPIO_J8_22
+    RPI_BPLUS_GPIO_J8_23
+    RPI_BPLUS_GPIO_J8_24
+    RPI_BPLUS_GPIO_J8_26
+    RPI_BPLUS_GPIO_J8_29
+    RPI_BPLUS_GPIO_J8_31
+    RPI_BPLUS_GPIO_J8_32
+    RPI_BPLUS_GPIO_J8_33
+    RPI_BPLUS_GPIO_J8_35
+    RPI_BPLUS_GPIO_J8_36
+    RPI_BPLUS_GPIO_J8_37
+    RPI_BPLUS_GPIO_J8_38
+    RPI_BPLUS_GPIO_J8_40
+    
     ) );
 
 
@@ -546,14 +602,17 @@ _register_exported_constants( qw(
 use constant {
     BCM2835_PWM_CONTROL     => 0,
     BCM2835_PWM_STATUS      => 1,
+    BCM2835_PWM_DMAC        => 2,
     BCM2835_PWM0_RANGE      => 4,
     BCM2835_PWM0_DATA       => 5,
+    BCM2835_PWM_FIF1        => 6,
     BCM2835_PWM1_RANGE      => 8,
     BCM2835_PWM1_DATA       => 9,
 
     BCM2835_PWMCLK_CNTL     => 40,
     BCM2835_PWMCLK_DIV      => 41,
-
+    BCM2835_PWM_PASSWRD     => (0x5A << 24),
+    
     BCM2835_PWM1_MS_MODE   => 0x8000, # Run in MS mode
     BCM2835_PWM1_USEFIFO   => 0x2000, # Data from FIFO
     BCM2835_PWM1_REVPOLAR  => 0x1000, # Reverse polarity
@@ -569,18 +628,35 @@ use constant {
     BCM2835_PWM0_REPEATFF  => 0x0004, # Repeat last value if FIFO empty
     BCM2835_PWM0_SERIAL    => 0x0002, # Run in serial mode
     BCM2835_PWM0_ENABLE    => 0x0001, # Channel Enable
+    
+    BCM2835_PWM_CLOCK_DIVIDER_2048  => 2048, #   /*!< 2048 = 9.375kHz */
+    BCM2835_PWM_CLOCK_DIVIDER_1024  => 1024, #     /*!< 1024 = 18.75kHz */
+    BCM2835_PWM_CLOCK_DIVIDER_512   => 512, #      /*!< 512 = 37.5kHz */
+    BCM2835_PWM_CLOCK_DIVIDER_256   => 256, #      /*!< 256 = 75kHz */
+    BCM2835_PWM_CLOCK_DIVIDER_128   => 128, #      /*!< 128 = 150kHz */
+    BCM2835_PWM_CLOCK_DIVIDER_64    => 64, #       /*!< 64 = 300kHz */
+    BCM2835_PWM_CLOCK_DIVIDER_32    => 32, #       /*!< 32 = 600.0kHz */
+    BCM2835_PWM_CLOCK_DIVIDER_16    => 16, #       /*!< 16 = 1.2MHz */
+    BCM2835_PWM_CLOCK_DIVIDER_8     => 8, #        /*!< 8 = 2.4MHz */
+    BCM2835_PWM_CLOCK_DIVIDER_4     => 4, #        /*!< 4 = 4.8MHz */
+    BCM2835_PWM_CLOCK_DIVIDER_2     => 2, #        /*!< 2 = 9.6MHz, fastest you can get */
+    BCM2835_PWM_CLOCK_DIVIDER_1     => 1, #        /*!< 1 = 4.6875kHz, same as divider 4096 */
+    
 };
 
 _register_exported_constants( qw(
     pwm
     BCM2835_PWM_CONTROL
     BCM2835_PWM_STATUS
+    BCM2835_PWM_DMAC
     BCM2835_PWM0_RANGE 
     BCM2835_PWM0_DATA
+    BCM2835_PWM_FIF1
     BCM2835_PWM1_RANGE 
     BCM2835_PWM1_DATA 
     BCM2835_PWMCLK_CNTL
-    BCM2835_PWMCLK_DIV 
+    BCM2835_PWMCLK_DIV
+    BCM2835_PWM_PASSWRD
     BCM2835_PWM1_MS_MODE
     BCM2835_PWM1_USEFIFO
     BCM2835_PWM1_REVPOLAR
@@ -595,6 +671,20 @@ _register_exported_constants( qw(
     BCM2835_PWM0_REPEATFF
     BCM2835_PWM0_SERIAL
     BCM2835_PWM0_ENABLE
+    
+    BCM2835_PWM_CLOCK_DIVIDER_2048 
+    BCM2835_PWM_CLOCK_DIVIDER_1024  
+    BCM2835_PWM_CLOCK_DIVIDER_512  
+    BCM2835_PWM_CLOCK_DIVIDER_256 
+    BCM2835_PWM_CLOCK_DIVIDER_128  
+    BCM2835_PWM_CLOCK_DIVIDER_64  
+    BCM2835_PWM_CLOCK_DIVIDER_32  
+    BCM2835_PWM_CLOCK_DIVIDER_16  
+    BCM2835_PWM_CLOCK_DIVIDER_8  
+    BCM2835_PWM_CLOCK_DIVIDER_4  
+    BCM2835_PWM_CLOCK_DIVIDER_2 
+    BCM2835_PWM_CLOCK_DIVIDER_1 
+    
     ) );
 
 #-------------------------------------------------------------
@@ -685,10 +775,21 @@ _register_exported_constants( qw(
 
 {
     for my $method( qw(
-        gpio_fget gpio_get_eds get_pin gpio_fget_name
-        set_SPI0 set_I2C0 set_I2C1 set_UART0 set_UART1
-        set_CTS0 set_CTS1 set_PWM0
-        spi_transfern spi_transfernb spi_writenb
+        gpio_fget
+        gpio_get_eds
+        get_pin
+        gpio_fget_name
+        set_SPI0
+        set_I2C0
+        set_I2C1
+        set_UART0
+        set_UART1
+        set_CTS0
+        set_CTS1
+        set_PWM0
+        spi_transfern
+        spi_transfernb
+        spi_writenb
     ) ) {
         no strict 'refs';
         my $subkey  = __PACKAGE__  . qq(::$method);
@@ -697,16 +798,66 @@ _register_exported_constants( qw(
     }
     
     for my $method( qw(
-        peri_read peri_read_nb peri_write peri_write_nb peri_set_bits
-        gpio_fsel gpio_set gpio_clr gpio_set_multi gpio_clr_multi
-        gpio_lev gpio_eds gpio_set_eds gpio_ren gpio_clr_ren
-        gpio_fen gpio_clr_fen gpio_hen gpio_clr_hen gpio_len
-        gpio_clr_len gpio_aren gpio_clr_aren gpio_afen gpio_clr_afen
-        gpio_pud gpio_pudclk gpio_pad gpio_set_pad delay
-        delayMicroseconds gpio_write gpio_write_multi gpio_write_mask
-        gpio_set_pud spi_begin spi_end spi_setBitOrder spi_setClockDivider
-        spi_setDataMode spi_chipSelect spi_setChipSelectPolarity spi_transfer
-        st_read st_delay
+        peri_read
+        peri_read_nb
+        peri_write
+        peri_write_nb
+        peri_set_bits
+        gpio_fsel
+        gpio_set
+        gpio_clr
+        gpio_set_multi
+        gpio_clr_multi
+        gpio_lev
+        gpio_eds
+        gpio_set_eds
+        gpio_eds_multi
+        gpio_set_eds_multi
+        gpio_ren
+        gpio_clr_ren
+        gpio_fen
+        gpio_clr_fen
+        gpio_hen
+        gpio_clr_hen
+        gpio_len
+        gpio_clr_len
+        gpio_aren
+        gpio_clr_aren
+        gpio_afen
+        gpio_clr_afen
+        gpio_pud
+        gpio_pudclk
+        gpio_pad
+        gpio_set_pad
+        delay
+        delayMicroseconds
+        gpio_write
+        gpio_write_multi
+        gpio_write_mask
+        gpio_set_pud
+        spi_begin
+        spi_end
+        spi_setBitOrder
+        spi_setClockDivider
+        spi_setDataMode
+        spi_chipSelect
+        spi_setChipSelectPolarity
+        spi_transfer
+        st_read
+        st_delay
+        
+        peripherals
+        gpio
+        pwm
+        clk
+        pads
+        spi0
+        bsc0
+        bsc1
+        st
+        peripherals_base
+        uses_dmb
+        
     ) ) {
         no strict 'refs';
         my $subkey  = __PACKAGE__  . qq(::$method);
@@ -774,31 +925,25 @@ sub hipi_get_pin {
 sub hipi_gpio_fget_name {
     my($pinid) = @_;
     return 'UNKNOWN' if $pinid < 0 || $pinid > 31;
-    given ( hipi_gpio_fget( $pinid )  ) {
-        when(  [ BCM2835_GPIO_FSEL_INPT ] ) {
-            return 'INPUT';
-        }
-        when(  [ BCM2835_GPIO_FSEL_OUTP ] ) {
-            return 'OUTPUT';
-        }
-        when(  [ BCM2835_GPIO_FSEL_ALT0 ] ) {
-            return $_altnames[$pinid]->[0];
-        }
-        when(  [ BCM2835_GPIO_FSEL_ALT1 ] ) {
-            return $_altnames[$pinid]->[1];
-        }
-        when(  [ BCM2835_GPIO_FSEL_ALT2 ] ) {
-            return $_altnames[$pinid]->[2];
-        }
-        when(  [ BCM2835_GPIO_FSEL_ALT3 ] ) {
-            return $_altnames[$pinid]->[3];
-        }
-        when(  [ BCM2835_GPIO_FSEL_ALT4 ] ) {
-            return $_altnames[$pinid]->[4];
-        }
-        when(  [ BCM2835_GPIO_FSEL_ALT5 ] ) {
-            return $_altnames[$pinid]->[5];
-        }
+    
+    my $checkval = hipi_gpio_fget( $pinid );
+    
+    if ( $checkval == BCM2835_GPIO_FSEL_INPT) {
+        return 'INPUT';
+    } elsif ( $checkval == BCM2835_GPIO_FSEL_OUTP) {
+        return 'OUTPUT';
+    } elsif ( $checkval == BCM2835_GPIO_FSEL_ALT0) {
+        return $_altnames[$pinid]->[0];
+    } elsif ( $checkval == BCM2835_GPIO_FSEL_ALT1) {
+        return $_altnames[$pinid]->[1];
+    } elsif ( $checkval == BCM2835_GPIO_FSEL_ALT2) {
+        return $_altnames[$pinid]->[2];
+    } elsif ( $checkval == BCM2835_GPIO_FSEL_ALT3) {
+        return $_altnames[$pinid]->[3];
+    } elsif ( $checkval == BCM2835_GPIO_FSEL_ALT4) {
+        return $_altnames[$pinid]->[4];
+    } elsif ( $checkval == BCM2835_GPIO_FSEL_ALT5) {
+        return $_altnames[$pinid]->[5];
     }
 }
 
