@@ -2,7 +2,7 @@
 # Package       HiPi::Constant::BoardRev2
 # Description:  Constants for Raspberry Pi board revision 2
 # Created       Fri Nov 23 22:32:56 2012
-# SVN Id        $Id: BoardRev2.pm 970 2013-03-05 23:10:20Z Mark Dootson $
+# SVN Id        $Id: BoardRev2.pm 13 2015-03-29 21:36:38Z Mark Dootson $
 # Copyright:    Copyright (c) 2012 Mark Dootson
 # Licence:      This work is free software; you can redistribute it and/or modify it 
 #               under the terms of the GNU General Public License as published by the 
@@ -109,6 +109,10 @@ use constant {
     I2C0_SCL	           => 29,
     I2C1_SDA	           => 2,
     I2C1_SCL	           => 3,
+    I2C_SDA	               => 2,
+    I2C_SCL	               => 3,
+    ID_SD	               => 0,
+    ID_SC	               => 1,
     
     RPI_PUD_NULL           => -1,
     RPI_PUD_OFF            => 0,
@@ -138,6 +142,38 @@ use constant {
     WPI_PIN_18  => 29,
     WPI_PIN_19  => 30,
     WPI_PIN_20  => 31,
+    
+    # generic RPI const
+    # all pins
+    RPI_PIN_3  =>  2,
+    RPI_PIN_5  =>  3,
+    RPI_PIN_7  =>  4,
+    RPI_PIN_8  => 14,
+    RPI_PIN_10 => 15,
+    RPI_PIN_11 => 17,
+    RPI_PIN_12 => 18,
+    RPI_PIN_13 => 27,
+    RPI_PIN_15 => 22,
+    RPI_PIN_16 => 23,
+    RPI_PIN_18 => 24,
+    RPI_PIN_19 => 10,
+    RPI_PIN_21 =>  9,
+    RPI_PIN_22 => 25,
+    RPI_PIN_23 => 11,
+    RPI_PIN_24 =>  8,
+    RPI_PIN_26 =>  7,
+    RPI_PIN_27 => 0,
+    RPI_PIN_28 => 1,
+    RPI_PIN_29 => 5,
+    RPI_PIN_31 => 6,
+    RPI_PIN_32 => 12,
+    RPI_PIN_33 => 13,
+    RPI_PIN_35 => 19,
+    RPI_PIN_36 => 16,
+    RPI_PIN_37 => 26,
+    RPI_PIN_38 => 20,
+    RPI_PIN_40 => 21,
+    
 };
 
 our @_rpi_const = qw(
@@ -153,9 +189,39 @@ our @_rpi_const = qw(
     RPI_PINMODE_INPT RPI_PINMODE_OUTP RPI_PINMODE_ALT0 RPI_PINMODE_ALT1
     RPI_PINMODE_ALT2 RPI_PINMODE_ALT3 RPI_PINMODE_ALT4 RPI_PINMODE_ALT5
     RPI_PUD_NULL RPI_PUD_OFF RPI_PUD_DOWN RPI_PUD_UP
+    
+    RPI_PIN_3
+    RPI_PIN_5
+    RPI_PIN_7 
+    RPI_PIN_8  
+    RPI_PIN_10 
+    RPI_PIN_11 
+    RPI_PIN_12 
+    RPI_PIN_13 
+    RPI_PIN_15 
+    RPI_PIN_16 
+    RPI_PIN_18 
+    RPI_PIN_19 
+    RPI_PIN_21 
+    RPI_PIN_22
+    RPI_PIN_23 
+    RPI_PIN_24 
+    RPI_PIN_26 
+    RPI_PIN_27 
+    RPI_PIN_28 
+    RPI_PIN_29 
+    RPI_PIN_31 
+    RPI_PIN_32 
+    RPI_PIN_33 
+    RPI_PIN_35 
+    RPI_PIN_36
+    RPI_PIN_37 
+    RPI_PIN_38
+    RPI_PIN_40 
+    
     gpio_2_rpitext );
 
-our @_i2c_const = qw( I2C0_SDA I2C0_SCL I2C1_SDA I2C1_SCL );
+our @_i2c_const = qw( I2C0_SDA I2C0_SCL I2C1_SDA I2C1_SCL I2C_SDA I2C_SCL ID_SD ID_SC );
 
 our @_wiring_const = qw(
         WPI_PIN_0  WPI_PIN_1  WPI_PIN_2  WPI_PIN_3  WPI_PIN_4
