@@ -2,7 +2,7 @@
 # Package       HiPi::Device::GPIO::Pin
 # Description:  Pin
 # Created       Wed Feb 20 04:37:38 2013
-# SVN Id        $Id: Pin.pm 1759 2013-04-27 13:53:07Z Mark Dootson $
+# SVN Id        $Id: Pin.pm 22 2016-03-04 21:38:30Z Mark Dootson $
 # Copyright:    Copyright (c) 2013 Mark Dootson
 # Licence:      This work is free software; you can redistribute it and/or modify it 
 #               under the terms of the GNU General Public License as published by the 
@@ -22,7 +22,7 @@ use Fcntl;
 use HiPi::Constant qw( :raspberry );
 use HiPi;
 
-our $VERSION ='0.33';
+our $VERSION ='0.35';
 
 __PACKAGE__->create_accessors( qw( pinroot valfh ) );
 
@@ -114,26 +114,24 @@ sub _do_getinterrupt {
 
 sub _do_setinterrupt {
     my ($self, $newedge) = @_;
-   
+    
+    $newedge ||= RPI_INT_NONE;
+    
     my $stredge = 'none';
     
     $newedge = RPI_INT_FALL if $newedge eq 'falling';
     $newedge = RPI_INT_RISE if $newedge eq 'rising';
     $newedge = RPI_INT_BOTH if $newedge eq 'both';
+    $newedge = RPI_INT_NONE if $newedge eq 'none';
     
-    given( $newedge ) {
-        when( [ RPI_INT_AFALL, RPI_INT_FALL, RPI_INT_LOW, 'falling'  ] ) {
-            $stredge = 'falling';
-        }
-        when( [ RPI_INT_ARISE, RPI_INT_RISE, RPI_INT_HIGH, 'rising'  ] ) {
-            $stredge = 'rising';
-        }
-        when( [ RPI_INT_BOTH, 'both'  ] ) {
-            $stredge = 'both';
-        }
-        default {
-            $stredge = 'none';
-        }
+    if ( $newedge == RPI_INT_AFALL || $newedge == RPI_INT_FALL || $newedge == RPI_INT_LOW  ) {
+        $stredge = 'falling';
+    } elsif( $newedge == RPI_INT_ARISE || $newedge == RPI_INT_RISE || $newedge == RPI_INT_HIGH  ) {
+        $stredge = 'rising';
+    } elsif( $newedge == RPI_INT_BOTH ) {
+        $stredge = 'both';
+    } else {
+        $stredge = 'none';
     }
     
     my $fh = _open_file( $self->pinroot . '/edge' );
@@ -145,20 +143,17 @@ sub _do_setinterrupt {
 sub _do_setpud {
     my($self, $pudval) = @_;
     my $pudchars = 'error';
-    given( $pudval ) {
-        when([ RPI_PUD_OFF ]) {
-            $pudchars = 'clear';
-        }
-        when([ RPI_PUD_UP ]) {
-            $pudchars = 'up';
-        }
-        when([ RPI_PUD_DOWN ]) {
-            $pudchars = 'down';
-        }
-        default {
-            croak(qq(Incorrect PUD setting $pudval));
-        }
+    
+    if ( $pudval == RPI_PUD_OFF ) {
+        $pudchars = 'clear';
+    } elsif ($pudval == RPI_PUD_UP ) {
+        $pudchars = 'up';
+    } elsif ($pudval == RPI_PUD_DOWN ) {
+        $pudchars = 'down';
+    } else {
+        croak(qq(Incorrect PUD setting $pudval));
     }
+    
     my $pinid = $self->pinid;
     HiPi::system_sudo(qq(hipi-pud $pinid $pudchars)) and croak qq(failed to set pud restistor for $pinid : $!);
     return 1;
