@@ -2,8 +2,8 @@
 # Package       HiPi::Utils
 # Description:  HiPi Utilities
 # Created       Sun Feb 24 05:16:17 2013
-# SVN Id        $Id: Utils.pm 1760 2013-05-21 02:24:24Z Mark Dootson $
-# Copyright:    Copyright (c) 2013 Mark Dootson
+# SVN Id        $Id: Utils.pm 24 2016-03-05 12:23:13Z Mark Dootson $
+# Copyright:    Copyright (c) 2013-2015 Mark Dootson
 # Licence:      This work is free software; you can redistribute it and/or modify it 
 #               under the terms of the GNU General Public License as published by the 
 #               Free Software Foundation; either version 3 of the License, or any later 
@@ -20,8 +20,9 @@ use Carp;
 require Exporter;
 use base qw( Exporter );
 use XSLoader;
+use HiPi::RaspberryPi qw( :all );
 
-our $VERSION ='0.33';
+our $VERSION ='0.35';
 
 our $defaultuser = 'pi';
 
@@ -38,54 +39,24 @@ our @EXPORT_OK = qw(
     is_unix
     is_raspberry
     is_mac
+    is_raspberry_2
+    is_raspberry_3
+    uses_device_tree
 );
                     
 our %EXPORT_TAGS = ( all => \@EXPORT_OK );
 
-#---------------------------------------------------
-# Allow this code to run on none raspberry platforms
-#---------------------------------------------------
-
-our ($_israspberry, $_isunix, $_iswindows, $_ismac, $_homedir) = (0,0,0,0, '');
-
-{
-    # Platform
-    if( $^O =~ /^mswin/i ) {
-        $_iswindows = 1;
-    } elsif( $^O =~ /^darwin/i ) {
-        $_ismac = 1;
-    } else {
-        $_isunix = 1;
-        # clean our path for safety
-        local $ENV{PATH} = '/bin:/usr/bin:/usr/local/bin';
-        my $checkcmd = qx(/bin/cat /proc/cpuinfo);
-        $_israspberry = ( $checkcmd =~ /BCM2708/ ) ? 1 : 0;
-    }
-    
-    # Home Dir
-    if( $_iswindows) {
-        require Win32;
-        $_homedir = Win32::GetFolderPath( 0x001C, 1);
-        $_homedir = Win32::GetShortPathName( $_homedir );
-        $_homedir =~ s/\\/\//g;
-    } else {
-        $_homedir = (getpwuid($<))[7];
-    }
-    
-    unless( -d $_homedir && -w $_homedir ) {
-        croak qq(Unable to access home directory $_homedir);
-    }
-    
-}
+sub is_raspberry { system_is_raspberry; }
+sub is_raspberry_2 { system_is_raspberry_2; }
+sub is_raspberry_3 { system_is_raspberry_3; }
+sub uses_device_tree { system_uses_device_tree; }
+sub is_windows { system_is_windows; }
+sub is_mac { system_is_mac; }
+sub is_unix { system_is_unix; }
+sub home_directory { system_home_directory; }
 
 XSLoader::load('HiPi::Utils', $VERSION) if is_raspberry();
 
-sub is_raspberry { $_israspberry; }
-sub is_windows { $_iswindows; }
-sub is_mac { $_ismac; }
-sub is_unix { $_isunix; }
-sub home_directory { $_homedir; }
-
 sub get_groups {
     my $rhash = {};
     return $rhash unless is_raspberry;
@@ -252,7 +223,7 @@ sub set_udev_rules {
         }
     }
     
-    if( $rh->{spi}->{active} ) {
+    if( $rh->{spi}->{active} && !uses_device_tree ) {
         my $lineout = 'KERNEL=="spidev*", SUBSYSTEM=="spidev", GROUP="REPLGROUPNAME", MODE="0660"';
         my $group = $rh->{spi}->{group};
         $lineout =~ s/REPLGROUPNAME/$group/g;
@@ -291,7 +262,6 @@ sub parse_modprobe_conf {
     #options i2c_bcm2708 baudrate=100000
     #options spidev bufsiz=4096
     
-    
     unless( is_raspberry ) {
         # return a default set
         return { spidev => { active => 1, bufsiz => 4096 }, i2c_bcm2708 => { active => 1, baudrate => 100000 }, };
@@ -324,7 +294,7 @@ sub set_modprobe_conf {
     require HiPi;
     my $modfile = '/etc/modprobe.d/hipi.conf';
     
-    return unless( is_raspberry );
+    return unless( is_raspberry && !uses_device_tree );
     
     open my $fh, '>', $modfile or croak qq(Failed to open $modfile : $!);
     print $fh qq(# File autogenerated by hipi-control\n\n);
@@ -370,6 +340,14 @@ sub drop_permissions_name {
     }
 }
 
+sub drop_permissions_id {
+    my($targetuid, $targetgid) = @_;
+    _drop_permissions_id($targetuid, $targetgid);
+    $> = $targetuid;
+    $< = $targetuid;
+    $) = $targetgid;
+    $( = $targetgid;
+}
 1;
 
 __END__
