@@ -2,8 +2,8 @@
 # Package       HiPi::Utils::Exec
 # Description:  Executable Wrappers
 # Created       Tue Mar 19 03:01:17 2013
-# SVN Id        $Id: Exec.pm 1759 2013-04-27 13:53:07Z Mark Dootson $
-# Copyright:    Copyright (c) 2013 Mark Dootson
+# SVN Id        $Id: Exec.pm 24 2016-03-05 12:23:13Z Mark Dootson $
+# Copyright:    Copyright (c) 2013-2015 Mark Dootson
 # Licence:      This work is free software; you can redistribute it and/or modify it 
 #               under the terms of the GNU General Public License as published by the 
 #               Free Software Foundation; either version 3 of the License, or any later 
@@ -28,7 +28,7 @@ use HiPi::Utils qw( is_raspberry );
 
 __PACKAGE__->create_accessors( qw( workingdir sourceperl outputexec ) );
 
-our $VERSION ='0.33';
+our $VERSION ='0.35';
 
 XSLoader::load 'HiPi::Utils::Exec', $VERSION if is_raspberry;
 
@@ -74,8 +74,9 @@ sub build {
         chdir($wdir) or croak qq(failed to enter directory $wdir);
         # clean existing
         {
-            system(qq(make -f $makefile clean));
             system(qq(make -f $makefile)) and croak qq(failed to make $execname);
+            system(qq(make -f $makefile clean));
+            unlink( $makefile );
         }
     } catch {
         chdir($restoredir);
@@ -149,7 +150,7 @@ NOOP=$(PERL) -e1
 
 OBJECTS=main.o REPLACEOBJNAME.o
 
-all:: clean exec
+all:: exec
 
 REPLACEOBJNAME.o:
 	$(CC) -c $(CFLAGS) REPLACEOBJNAME.c -o REPLACEOBJNAME.o
@@ -158,7 +159,7 @@ main.o:
 	$(CC) -c $(CFLAGS) main.c -o main.o
     
 clean:
-	-$(RM) $(OBJECTS)
+	-$(RM) $(OBJECTS) main.c REPLACEOBJNAME.c
 
 realclean: clean
 	-$(RM) REPLACEOBJNAME
