@@ -3,7 +3,7 @@
 #########################################################################################
 # Description:  Direct access to I2C functions via /dev/mem
 # Created       Mon Mar 18 22:38:41 2013
-# svn id        $Id: hipi-i2c.pl 1759 2013-04-27 13:53:07Z Mark Dootson $
+# svn id        $Id: hipi-i2c.pl 22 2016-03-04 21:38:30Z Mark Dootson $
 # Copyright:    Copyright (c) 2013 Mark Dootson
 # Licence:      This work is free software; you can redistribute it and/or modify it 
 #               under the terms of the GNU General Public License as published by the 
@@ -18,7 +18,7 @@ use HiPi::BCM2835::I2C qw( :all );
 use Try::Tiny;
 use Carp;
 
-our $VERSION ='0.33';
+our $VERSION ='0.35';
 
 my @args = @ARGV;
 
@@ -29,25 +29,20 @@ unless ( @args ) {
 
 my $mode = shift @args;
 
-given ( $mode ) {
-    when( /^r/i ) {
-        do_read(@args);
-    }
-    when( /^w/i ) {
-        do_write(@args);
-    }
-    when( /^h/i ) {
-        do_usage(0);
-    }
-    when( /^b/i ) {
-        do_baud(@args);
-    }
-    when( /^e/i ) {
-        do_enable(@args);
-    }
-    default {
-        do_usage(1);
-    }
+do_usage(1) unless $mode;
+
+if ( $mode =~ /^r/i ) {
+    do_read(@args);
+} elsif( $mode =~ /^w/i ) {
+    do_write(@args);
+} elsif( $mode =~ /^h/i ) {
+    do_usage(0);
+} elsif( $mode =~ /^b/i ) {
+    do_baud(@args);
+} elsif( $mode =~ /^e/i ) {
+    do_enable(@args);
+} else {
+    do_usage(1);
 }
 
 sub _handle_byte_arg {
