@@ -3,7 +3,7 @@
 #########################################################################################
 # Description:  Access to pull up pull down functions via /dev/mem
 # Created       Mon Mar 18 22:38:41 2013
-# svn id        $Id: hipi-pud.pl 1759 2013-04-27 13:53:07Z Mark Dootson $
+# svn id        $Id: hipi-pud.pl 22 2016-03-04 21:38:30Z Mark Dootson $
 # Copyright:    Copyright (c) 2013 Mark Dootson
 # Licence:      This work is free software; you can redistribute it and/or modify it 
 #               under the terms of the GNU General Public License as published by the 
@@ -18,7 +18,7 @@ use HiPi::BCM2835 qw( :all );
 use Carp;
 use HiPi::RaspberryPi;
 
-our $VERSION ='0.33';
+our $VERSION ='0.35';
 
 my( $inputpinid, $inputaction ) = @ARGV;
 
@@ -37,19 +37,15 @@ $dev->gpio_set_pud($pinid, $pudaction);
 sub confirm_action {
     my $useraction = shift;
     my $rval;
-    given( lc($useraction) ) {
-        when(['c', 'clear', 'n', 'none']) {
-            $rval = BCM2835_GPIO_PUD_OFF;
-        }
-        when(['u', 'up']) {
-            $rval = BCM2835_GPIO_PUD_UP;
-        }
-        when(['d', 'down']) {
-            $rval = BCM2835_GPIO_PUD_DOWN;
-        }
-        default {
-            do_usage(1);
-        }
+    my $checkval = lc($useraction);
+    if ( $checkval eq 'c' || $checkval eq 'clear' || $checkval eq 'n' || $checkval eq 'none' ) {
+        $rval = BCM2835_GPIO_PUD_OFF;
+    } elsif( $checkval eq 'u' || $checkval eq 'up') {
+        $rval = BCM2835_GPIO_PUD_UP;
+    } elsif( $checkval eq 'd' || $checkval eq 'down') {
+        $rval = BCM2835_GPIO_PUD_DOWN;
+    } else {
+        do_usage(1);
     }
     return $rval;
 }
